/**
  ******************************************************************************
  * @file    BoostConverter.h
  * @author  Pascal Guttmann
  * @version v1
  * @date    14 Nov 2020
  * @brief   This file contains the function prototypes and definitions for the Boost Converter.
  ******************************************************************************
  */
#ifndef _BOOSTCONVERTER_h
#define _BOOSTCONVERTER_h


#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>

//Uncomment for Debug
///#define BC_DEBUG

//BoostConverter Pins

//BoostConverter defines
#define BC_PWM_PIN	9
#define BC_FB_PIN	A0
#define BC_HVDC_PIN	A4
#define BC_R_TOTAL	96200
#define BC_R_SENSE	2200
#define BC_ADC_RES	1024
#define BC_ADC_REF	5
#define BC_INPUT_VOLTAGE 12
#define BC_K_P 1
#define BC_T_I 150   //in ms
#define BC_UPDATETIME 512 //in us

#define BC_VOLT2INT(VOLT) (VOLT * (  (double)BC_ADC_RES * (double)BC_R_SENSE / (double)BC_R_TOTAL / (double) BC_ADC_REF ) )
#define BC_INT2VOLT(INT) (INT	 / (  (double)BC_ADC_RES * (double)BC_R_SENSE / (double)BC_R_TOTAL / (double) BC_ADC_REF ) )



void BC_setup(uint8_t voltage);

uint8_t BC_readOutputVoltage(void);

void BC_setTargetVoltage(uint8_t volts);
uint8_t BC_readTargetVoltage(void);
void BC_setStandby(bool onoff);
bool CF_service(void);



#ifdef __cplusplus
}
#endif

#endif /* _BOOSTCONVERTER_h */
