/**
  ******************************************************************************
  * @file    ClockFunctions.h
  * @author  Pascal Guttmann
  * @version v1
  * @date    15 Nov 2020
  * @brief   This file contains the function prototypes and definitions for the basic Clock functionality:
				- Store time, date, year, arbitrary number and mask
				- select the Source to display on Nixie Tubes
				- increment Time, Date and Year
  ******************************************************************************
  */
#ifndef _CLOCKFUNCTIONS_h
#define _CLOCKFUNCTIONS_h


#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <time.h>


//Uncomment for Debug
///#define CF_DEBUG

#define CF_YEARPRESET	2000 //For 2021 only "21" is sent by DCF77 thus Preset 2000
#define CF_TIMEZONE		0

typedef enum {
	Time,
	Date,
	Year,
	Alt
}CF_Source;


void CF_setup(void);
void CF_setMask(uint8_t _mask[4]);
void CF_getMask(uint8_t* arr);
void CF_startMinute(void);
void CF_setTime(uint8_t time[4]);
void CF_getTime(uint8_t* arr);
void CF_setDate(uint8_t date[4]);
void CF_getDate(uint8_t* arr);
void CF_setYear(uint8_t year[2]);
void CF_getYear(uint8_t* arr);
void CF_setAlt(uint8_t alt[4]);
void CF_getAlt(uint8_t* arr);
void CF_setSourceSelect(CF_Source src);
CF_Source CF_getSourceSelect(void);
void CF_increment(void);
void CF_setTime_unix(time_t time);
void CF_ServiceACK(void);
bool CF_service(void);
void CF_setStandby(bool onoff);
void CF_setBacklightStartMode(uint8_t val);
uint8_t CF_getBacklightStartMode(void);
void CF_setFlickerMode(bool val);
bool CF_getFlickerMode(void);

void CF_printSrc(void);


#ifdef __cplusplus
}
#endif

#endif /* _CLOCKFUNCTIONS_h */
