/**
  ******************************************************************************
  * @file    ShiftRegister.cpp
  * @author  Pascal Guttmann
  * @version v1
  * @date    15 Nov 2020
  * @brief   This file contains the sourcecode to display something on the Nixie Tubes.
  ******************************************************************************
  */

#include "ShiftRegister.h"
#include <Arduino.h>
#include <SPI.h>


//ShiftReg defines
#define SR_RSTPIN 8
#define SR_LCLPIN 7
#define SR_CLKSPEED 15000000

/**
  * @brief  Sets up the SPI communication to transfer data to the ShiftRegisters.
  * @param  void
  * @retval void
  */
void SR_setup(void) {
	SPI.begin();

	digitalWrite(SR_RSTPIN, HIGH);
	pinMode(SR_RSTPIN, OUTPUT);

	digitalWrite(SR_LCLPIN, LOW);
	pinMode(SR_LCLPIN, OUTPUT);

	SR_clear();

#ifdef SR_DEBUG
	Serial.println("Shift Register initialized.");
#endif
}


/**
  * @brief  Clears the contents of the ShiftRegister, therefore nothing is displayed.
  * @param  void
  * @retval void
  */
void SR_clear(void) {
	digitalWrite(SR_RSTPIN, LOW);

	digitalWrite(SR_LCLPIN, LOW);
	digitalWrite(SR_LCLPIN, HIGH);
	digitalWrite(SR_LCLPIN, LOW);

	digitalWrite(SR_RSTPIN, HIGH);

#ifdef SR_DEBUG
	Serial.println("Shift Register cleared.");
#endif
}

/**
  * @brief  Outputs the numbers of the array to the Nixie Tubes. Values other than 0...9 are ignored and the Tube is turned off.
  * @param  Array of numbers to display on the Tubes. number[0] == Least Significant Digit.
  * @retval void
  */
void SR_printNixie(uint8_t number[4]){
	uint64_t SR_data = 0x0;

	for(int i = 0; i < 4 ; i++){
		if(0 <= number[i] && number[i] <= 9){
			SR_data |= ((uint64_t) 1 << (9 - number[i] + i * 10));
		}
	}

	SPI.beginTransaction(SPISettings(SR_CLKSPEED, LSBFIRST , SPI_MODE0));
	for (int i = 0; i < 5; i++) {
		SPI.transfer((uint8_t) ( (SR_data >> (i * 8)) & 0xFF ) );
	}
	SPI.endTransaction();

	digitalWrite(SR_LCLPIN, LOW);
	digitalWrite(SR_LCLPIN, HIGH);
	digitalWrite(SR_LCLPIN, LOW);
}
